/**
 * navigation.js
 *
 * Handles toggling the navigation menu for small screens.
 */
( function() {
	var container, button, menu;

	container = document.getElementById( 'site-navigation' );
	if ( ! container ) {
		return;
	}

	button = container.getElementsByClassName( 'menu-toggle' )[0];
	if ( 'undefined' === typeof button ) {
		return;
	}

	menu = container.getElementsByTagName( 'ul' )[0];

	// Hide menu toggle button if menu is empty and return early.
	if ( 'undefined' === typeof menu ) {
		button.style.display = 'none';
		return;
	}

	if ( -1 === menu.className.indexOf( 'nav-menu' ) ) {
		menu.className += ' nav-menu';
	}

	button.onclick = function() {
		if ( -1 !== container.className.indexOf( 'main-small-navigation' ) ) {
			container.className = container.className.replace( 'main-small-navigation', 'main-navigation' );
		} else {
			container.className = container.className.replace( 'main-navigation', 'main-small-navigation' );
		}
	};
} )();

// Show Submenu on click on touch enabled deviced
( function () {
    var container;
    container = document.getElementById( 'site-navigation' );

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( container ) {
        var touchStartFn, i,
            parentLink = container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( ( 'ontouchstart' in window ) && ( window.matchMedia( "( min-width: 768px ) " ).matches ) ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, i;

                if ( ! menuItem.classList.contains( 'focus' ) ) {
                    e.preventDefault();
                    for ( i = 0; i < menuItem.parentNode.children.length; ++i ) {
                        if ( menuItem === menuItem.parentNode.children[i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[i].classList.remove( 'focus' );
                    }
                    menuItem.classList.add( 'focus' );
                } else {
                    menuItem.classList.remove( 'focus' );
                }
            };

            for ( i = 0; i < parentLink.length; ++i ) {
                parentLink[i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( container ) );
} ) ();

/**
 * Fixes menu out of viewport
 */
( function ( $ ) {
	var handlerIn, handlerOut,
		container = document.getElementById( 'site-navigation' );

	// For touchscreen and mouse enter
	handlerIn = function () {
		if ( $( this ).children( 'ul.sub-menu' ).length > 0 ) {

			// Get document width
			var docWidth = $( document ).width();

			// Get window width
			var windowWidth = $( window ).width();

			// Condition where menu item goes out of viewport
			if ( docWidth > windowWidth ) {
				$( this ).children( ' ul.sub-menu' ).addClass( 'spacious-menu--left' );
			}
		}
	};

	// For mouse leave
	handlerOut = function () {
		$( this ).children( ' ul.sub-menu' ).removeClass( 'spacious-menu--left' );
	};

	// Desktop
	$( '.main-navigation  .menu-item-has-children, .main-navigation .page_item_has_children' ).hover( handlerIn, handlerOut );


	// Touch screen
	( function ( container ) {
		var i,
			parentLink = container.querySelectorAll( '.main-navigation  .menu-item-has-children, .main-navigation .page_item_has_children' );

		if ( 'ontouchstart' in window ) {

			for ( i = 0; i < parentLink.length; ++i ) {
				parentLink[ i ].addEventListener( 'touchstart', handlerIn, false );
			}
		}
	} )( container );

} )( jQuery );
